@@ -93,9 +93,6 @@
 #define CLIENT_FILL                     (CLIENT_FILL_VERT | \
                                          CLIENT_FILL_HORIZ)
 
-
-#define STRUTS_SIZE                     12
-
 #ifndef CLIENT_MIN_VISIBLE
 #define CLIENT_MIN_VISIBLE              15
 #endif
@@ -469,6 +466,10 @@ gboolean                 clientToggleMaximizedAtPoint           (Client *,
                                                                  gint,
                                                                  int,
                                                                  gboolean);
+gboolean                 clientMoveToMonitorByDirectionPossible (Client *,
+                                                                 gint);
+void                     clientMoveToMonitorByDirection         (Client *,
+                                                                 gint);
 gboolean                 clientTile                             (Client *,
                                                                  gint,
                                                                  gint,
@@ -490,6 +491,7 @@ void                     clientDecOpacity                       (Client *);
 void                     clientUpdateCursor                     (Client *);
 void                     clientUpdateAllCursor                  (ScreenInfo *);
 void                     clientScreenResize                     (ScreenInfo *,
+                                                                 gboolean,
                                                                  gboolean);
 void                     clientButtonPress                      (Client *,
                                                                  Window,
