@@ -34,14 +34,6 @@
 #include "screen.h"
 #include "client.h"
 
-enum
-{
-    VBLANK_OFF = 0,
-    VBLANK_AUTO,
-    VBLANK_XPRESENT,
-    VBLANK_GLX
-};
-
 gboolean                 compositorIsUsable                     (DisplayInfo *);
 gboolean                 compositorIsActive                     (ScreenInfo *);
 void                     compositorAddWindow                    (DisplayInfo *,
@@ -87,4 +79,9 @@ void                     compositorWindowSetOpacity             (DisplayInfo *,
 void                     compositorRebuildScreen                (ScreenInfo *);
 gboolean                 compositorTestServer                   (DisplayInfo *);
 
+vblankMode               compositorParseVblankMode              (const gchar *);
+void                     compositorSetVblankMode                (ScreenInfo *,
+                                                                 vblankMode);
+
+
 #endif /* INC_COMPOSITOR_H */
