@@ -355,14 +355,9 @@ clientPassFocus (ScreenInfo *screen_info, Client *c, GList *exclude_list)
 
     look_in_layer = (c ? c->win_layer : WIN_LAYER_NORMAL);
     new_focus = NULL;
-    current_focus = client_focus;
+    current_focus = clientGetFocusOrPending ();
 
-    if (pending_focus)
-    {
-        current_focus = pending_focus;
-    }
-
-    if ((c || current_focus) && (c != current_focus))
+    if ((current_focus != NULL) && (c != current_focus))
     {
         return;
     }
@@ -784,7 +779,7 @@ delayed_focus_cb (gpointer data)
     focus_timeout = 0;
     delayed_focus = NULL;
 
-    return (FALSE);
+    return FALSE;
 }
 
 void
