@@ -18,7 +18,7 @@
 
         oroborus - (c) 2001 Ken Lynch
         Metacity - (c) 2001 Havoc Pennington
-        xfwm4    - (c) 2002-2020 Olivier Fourdan
+        xfwm4    - (c) 2002-2022 Olivier Fourdan
 
  */
 
@@ -80,8 +80,8 @@
 #define WIN_LAYER_NORMAL                        4
 #define WIN_LAYER_ONTOP                         6
 #define WIN_LAYER_DOCK                          8
-#define WIN_LAYER_ABOVE_DOCK                    10
-#define WIN_LAYER_FULLSCREEN                    12
+#define WIN_LAYER_FULLSCREEN                    10
+#define WIN_LAYER_ABOVE_DOCK                    12
 #define WIN_LAYER_NOTIFICATION                  14
 
 #define NET_WM_MOVERESIZE_SIZE_TOPLEFT          0
@@ -121,6 +121,8 @@
 #define STRUTS_BOTTOM_START_X                   10
 #define STRUTS_BOTTOM_END_X                     11
 
+#define STRUTS_SIZE                             12
+
 /* Convenient macro */
 #define HINTS_ACCEPT_INPUT(wmhints)     (!(wmhints) ||                                                              \
                                          ((wmhints) && !(wmhints->flags & InputHint)) ||                            \
@@ -282,15 +284,6 @@ gboolean                 setAtomIdManagerOwner                  (DisplayInfo *,
                                                                  Window);
 void                     updateXserverTime                      (DisplayInfo *);
 guint32                  getXServerTime                         (DisplayInfo *);
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-gboolean                 checkKdeSystrayWindow                  (DisplayInfo *,
-                                                                 Window);
-void                     sendSystrayReqDock                     (DisplayInfo *,
-                                                                 Window,
-                                                                 Window);
-Window                   getSystrayWindow                       (DisplayInfo *,
-                                                                 Atom);
-#endif
 
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
 gboolean                 getWindowStartupId                     (DisplayInfo *,
