@@ -32,6 +32,7 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
+#include "client.h"
 #include "event_filter.h"
 
 typedef enum
@@ -50,15 +51,16 @@ typedef enum
     MENU_OP_DELETE       = 1 << 10,
     MENU_OP_DESTROY      = 1 << 11,
     MENU_OP_WORKSPACES   = 1 << 12,
-    MENU_OP_QUIT         = 1 << 13,
-    MENU_OP_RESTART      = 1 << 14,
-    MENU_OP_ABOVE        = 1 << 15,
-    MENU_OP_BELOW        = 1 << 16,
-    MENU_OP_NORMAL       = 1 << 17,
-    MENU_OP_FULLSCREEN   = 1 << 18,
-    MENU_OP_UNFULLSCREEN = 1 << 19,
-    MENU_OP_CONTEXT_HELP = 1 << 20,
-    MENU_OP_OTHER        = 1 << 21
+    MENU_OP_MONITORS     = 1 << 13,
+    MENU_OP_QUIT         = 1 << 14,
+    MENU_OP_RESTART      = 1 << 15,
+    MENU_OP_ABOVE        = 1 << 16,
+    MENU_OP_BELOW        = 1 << 17,
+    MENU_OP_NORMAL       = 1 << 18,
+    MENU_OP_FULLSCREEN   = 1 << 19,
+    MENU_OP_UNFULLSCREEN = 1 << 20,
+    MENU_OP_CONTEXT_HELP = 1 << 21,
+    MENU_OP_OTHER        = 1 << 22
 }
 MenuOp;
 
@@ -104,7 +106,8 @@ struct _Menu
     gpointer data;
 };
 
-Menu                    *menu_default                           (GdkScreen *,
+Menu                    *menu_default                           (Client *c,
+                                                                 GdkScreen *,
                                                                  Window,
                                                                  MenuOp,
                                                                  MenuOp,
