@@ -163,9 +163,6 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
 ScreenInfo *
 myScreenInit (DisplayInfo *display_info, GdkScreen *gscr, unsigned long event_mask, gboolean replace_wm)
 {
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-    gchar selection[32];
-#endif
     ScreenInfo *screen_info;
     GdkWindow *event_win;
     PangoLayout *layout;
@@ -298,12 +295,6 @@ myScreenInit (DisplayInfo *display_info, GdkScreen *gscr, unsigned long event_ma
                     EnterWindowMask,
                     TRUE);
 
-#ifdef ENABLE_KDE_SYSTRAY_PROXY
-    g_snprintf (selection, sizeof (selection), "_NET_SYSTEM_TRAY_S%d", screen_info->screen);
-    screen_info->net_system_tray_selection = XInternAtom (display_info->dpy, selection, FALSE);
-    screen_info->systray = getSystrayWindow (display_info, screen_info->net_system_tray_selection);
-#endif
-
     screen_info->font_desc = NULL;
     screen_info->pango_attr_list = NULL;
     screen_info->box_gc = None;
@@ -902,3 +893,24 @@ myScreenUpdateFontAttr (ScreenInfo *screen_info)
     pango_attr_list_insert (screen_info->pango_attr_list, attr);
 }
 
+gboolean
+myScreenMaxSpaceForGeometry (ScreenInfo *screen_info,
+                             GdkRectangle *rect,
+                             GdkRectangle *dest)
+{
+    GdkRectangle screen_rect;
+
+    g_return_val_if_fail (screen_info != NULL, FALSE);
+    g_return_val_if_fail (rect != NULL, FALSE);
+
+    screen_rect.x = screen_info->params->xfwm_margins[STRUTS_LEFT];
+    screen_rect.y = screen_info->params->xfwm_margins[STRUTS_TOP];
+    screen_rect.width = screen_info->width -
+                        screen_info->params->xfwm_margins[STRUTS_RIGHT] -
+                        screen_info->params->xfwm_margins[STRUTS_LEFT];
+    screen_rect.height = screen_info->height -
+                         screen_info->params->xfwm_margins[STRUTS_TOP] -
+                         screen_info->params->xfwm_margins[STRUTS_BOTTOM];
+
+    return gdk_rectangle_intersect (&screen_rect, rect, dest);
+}
