@@ -78,6 +78,10 @@ enum
     KEY_MAXIMIZE_VERT,
     KEY_MAXIMIZE_WINDOW,
     KEY_MOVE,
+    KEY_MOVE_TO_MONITOR_DOWN,
+    KEY_MOVE_TO_MONITOR_LEFT,
+    KEY_MOVE_TO_MONITOR_RIGHT,
+    KEY_MOVE_TO_MONITOR_UP,
     KEY_MOVE_DOWN_WORKSPACE,
     KEY_MOVE_LEFT_WORKSPACE,
     KEY_MOVE_NEXT_WORKSPACE,
